pub async fn handshake(conn: &Connection, cwd: &str) -> Result<SessionId>Expand description
Run the ACP handshake and open a session rooted at cwd.
pub async fn handshake(conn: &Connection, cwd: &str) -> Result<SessionId>Run the ACP handshake and open a session rooted at cwd.